using Exam.Models;

namespace Exam.Services
{
    public interface IService
    {
        public List<Flight> ShowFlightsByDateAndCity(DateTime date, string city);
        public List<Hotel> ShowHotelsByDateAndCity(DateTime date, string city);
        public int AddReservavtion(Reservation flight);
        public bool RemoveReservavtions(List<int> ids);

        public void DecrementFlightSeats(int id);
        public void DecrementHotelRooms(int id);

    }
}
